module CoherentNoise

### Dependencies

# Language dependencies
using Random: Xoshiro, shuffle

# Third-party dependencies
using CircularArrays: CircularVector
using Distributions: Uniform
using FastPow
using ColorTypes: RGB
using ColorSchemes: ColorScheme

### Includes

include("docs.jl")
include("common.jl")
include("pattern.jl")
include("noise.jl")
include("fractal.jl")
include("modifier.jl")

### Exports

# Common
export AbstractSampler, sample, gen_image

# Noise
export NoiseSampler
export value_2d, value_3d, value_4d
export perlin_improved_2d, perlin_improved_3d, perlin_improved_4d
export simplex_2d, simplex_3d, simplex_4d
export opensimplex_2d, opensimplex_3d, opensimplex_4d
export opensimplex2_2d, opensimplex2_3d, opensimplex2_4d
export opensimplex2s_2d, opensimplex2s_3d, opensimplex2s_4d
export worley_2d, worley_3d, worley_4d

# Fractals
export FractalSampler
export fbm_fractal_2d, fbm_fractal_3d, fbm_fractal_4d
export billow_fractal_2d, billow_fractal_3d, billow_fractal_4d
export multi_fractal_2d, multi_fractal_3d, multi_fractal_4d
export hybrid_fractal_2d, hybrid_fractal_3d, hybrid_fractal_4d
export ridged_fractal_2d, ridged_fractal_3d, ridged_fractal_4d

# Patterns
export PatternSampler
export constant_1d, checkered_2d, cylinders_2d, spheres_3d

# Modifiers
export ModifierSampler
export cache, curve, mix, rotate, scale, select, terrace
export translate, turbulence, warp

end
